@@ -1,11 +1,20 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import logging
 from .data.data4info import d, identifiers, dnew, newidentifiers
+from .exceptions import NotValidISBNError
+
+logger = logging.getLogger(__name__)
 
 
 def infogroup(isbn):
     """ Language/Country of this ISBN """
+    # if isbn is not a valid ISBN this def can give a wrong result!
+    # -> do a minimal test
+    if len(isbn) not in (10, 13):
+        logger.critical('%s is not a valid ISBN' % isbn)
+        raise NotValidISBNError(isbn)
     dtxt = d
     idents = identifiers
     ixi, ixf = 0, 1
